/***************************************************************************************************
*                                           MINI-SENTINEL PROGRAM
****************************************************************************************************
* NAME:  
*
* PURPOSE:
*
* MAJOR STEPS: 
*
* KEY DEPENDENCIES/CONSTRAINTS/CAVEATS:
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Mini-Sentinel Coordinating Center
*  info@mini-sentinel.org
*
*--------------------------------------------------------------------------------------------------
* HISTORY:
*  Create date (mm/dd/yy):
*  Last modified date (mm/dd/yy): 
*  Version:
*
*  CHANGE LOG: 
*
*   Version   Date       Comment (reference external documentation when available)
*   -------   --------   -------------------------------------------------------------------------
*             mm/dd/yy
*
**************************************************************************************************/

/* System options */
options nosymbolgen nomlogic ;
options ls=100 nocenter ;

/*-------------------------------------------------------------------------------------------------
*                                        DEFINITIONS
*--------------------------------------------------------------------------------------------------
* MSCC     ... Mini-Sentinel Common-Components File 
*              Specific to each Data Partner/Data Site, the Common-Components defines key
*                 - macro variables (e.g. Data Partner ID, Min and Max Dates, MSCDM table names)   
*                 - libname assignments (e.g. libref INDATA is assigned to production MSCDM tables) 
*              NOTE: This parameter needs to be set by programmer at the Data Partner/Data Site
*
* MSReqID  ... Mini-Sentinel Project Request-ID
*              NOTE: This parameter needs to be set by the programmer preparing the Request-ID
*                    in coordination with the Mini-Sentinel Operations Center (MSOC)
*
* The following paths for the current request are automatically derived 
*    DPLOCAL  ... path for data created that remains local (i.e. behind the DP firewall)
*    MSOC     ... path for data created to share with MS Operations Center
*    INFOLDER ... path for program inputs (e.g. lookup data, include programs, include macros)
*    SASPROGRAMS ... path for the main SAS program for the request
*------------------------------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* NOTE: Data Partner/Data Site programmer defines parameters in this section */
/*----------------------------------------------------------------------------*/

/* Define Common Components Include File */
/* Example: //mini-sentinel/common-components/ms_common_components.sas */
%let MSCC = edit-path/ms_common_components.sas ;


**************************************************************************************************
*******                                  END OF USER INPUT                                  ******
*******                             DO NOT EDIT BELOW THIS LINE                             ******
*******                        (Consult with MSOC or MS team leader                         ******
*******                           if you feel edits are required)                           ******
**************************************************************************************************;

/* Include Common Components */
%inc "&MSCC" /source2 ;

/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing Request-ID defines the                   */
/*       parameter MSReqID in coordination with the MSOC               */
/*---------------------------------------------------------------------*/

/*-------------------------------------------------------------------------------------------------
* Specific requests are made up a project-ID, workplan-type, workplan-ID, unique-dpid, version-ID           
*--------------------------------------------------------------------------------------------------
*
*        If this is your request   . . . . .  then set parameter values as follows 
*   ---------------------------------     -------------------------------------------------------
*   [Task Order 7 - NME Dabigatran]       %let MSProjID = to07_nme_dabi ;  
*   [WorkPlan Type]                       %let MSWPType = ahr; 
*   [Workplan # 5]                        %let MSWPID = wp005 ; 
*   [Unique DP id]                        %let MSDPID = nsdp ;     
*   [Beta 3]                              %let MSVerID = b03 ;         
*   [use underscores as delimiter]        %let dlm = _ ;                
*
*   The example values above would produce a Request-ID equal to to07_nme_dabi_ahr_wp005_nsdp_b03
*
*--------------------------------------------------------------------------------------------------*/

* Specify project-ID, workplan-type, workplan-ID, workplan-type, unique-dpid, version-ID *;
%let MSProjID = edit-project-id ; 
%let MSWPType = edit-workplantype-id ;      
%let MSWPID   = edit-workplan-id ;        
%let MSDPID   = edit-unique DP-id ;   /* Note: set value to nsdp for non-specific DP type requests */
%let MSVerID  = edit-version-id ;        
%let dlm = _ ; 

* Request-ID *;
%let MSReqID = &MSProjID.&dlm.&MSWPType.&dlm.&MSWPID.&dlm.&MSDPID.&dlm.&MSVerID ;

* Delete macro variable used as delimiter as we no longer need it *;
%symdel dlm ; 


*-------------------------------------------------------------------------------------------------
* 0- Setup Environment
*-------------------------------------------------------------------------------------------------;

/*---------------------------------------------------------------------*/
/* NOTE: This is standard MSOC environment setup code -- Do Not Edit   */
/*---------------------------------------------------------------------*/

/* System options */
options obs=MAX ;
options msglevel=i ;
options mprint mprintnest ;
options errorcheck=strict errors=0 ;
options merror serror ;
options dkricond=error dkrocond=error mergenoby=warn;
options dsoptions=nonote2err noquotelenmax ;
options reuse=no ;
options fullstimer ;


/*------------------------------------------------------------------------------------------------
* NOTES:
*   For reasons of compatibility and standardization, paths must meet the following criteria:
*     1- Starting with the request subdirectory, all subdirectory names must be specified in
*        lower case (for UNIX compatibility)
*     2- Slashes must be forward-leaning slashes '/' (for UNIX compatibility)
*     3- Paths must end with a final forward-leaning slash '/' (extra slashes are fine)
*------------------------------------------------------------------------------------------------*/

/* Request-ID parameter value must be lower case */
%let MSReqID = %lowcase(&MSReqID) ;

/* Define request specific subdirectories */
%let DPLOCAL = &_root_dplocal.&MSReqID./dplocal/ ; 
%let MSOC = &_root_msoc.&MSReqID./msoc/ ;            
%let INFOLDER = &_root_inputfiles.&MSReqID./inputfiles/ ;  
%let SASPROGRAMS = &_root_sasprograms.&MSReqID./sasprograms/ ;                 

/* Clean up paths (e.g. convert slashes and add slashes when necessary) and validate that paths exist */
%let DPLOCAL = %ms_clean_path(&DPLOCAL) ;
%let MSOC = %ms_clean_path(&MSOC) ;
%let INFOLDER = %ms_clean_path(&INFOLDER) ;
%let SASPROGRAMS = %ms_clean_path(&SASPROGRAMS) ;

/* Assign libnames */
/* %ms_lib(libref-name, path-name, options=%str(options-name=options-value)) */
%ms_lib(dplocal, &DPLOCAL) 
%ms_lib(msoc, &MSOC) 
%ms_lib(infolder, &INFOLDER, options=%str(access=readonly));


**************************************************************************************************
*******                                  BEGIN PROGRAM                                     *******
**************************************************************************************************;

/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing request includes/writes                  */
/*       the rest of the program below                                 */
/*---------------------------------------------------------------------*/

*--------------------------------------------------------------------------------------------------
* 1- 
*--------------------------------------------------------------------------------------------------;
